==> kenexar-core-2.1.1.tar.gz: kenexar-core-2.1.1/README.md <==
<br />
<div align="center">
  <a href="https://github.com/Kenexar/kenexar-core">
    <img src="https://cloud.kenexar.eu/s/bQBApT3Sa56KBij/preview" alt="Logo" width="80" height="80">
  </a>

  <h3 align="center">Kenexar-Core</h3>

  <p align="center">
    This is the base Package for the most python projects from the KenexarEU Team.<br> Also is this project a collection of the most used code snippets.
    <br />
    <a href="https://kenexar.github.io/kenexar-core/"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://github.com/Kenexar/kenexar-core/issues">Report Bug</a>
    ·
    <a href="https://github.com/Kenexar/kenexar-core/issues">Request Feature</a>
  </p>
  <a align="center" href="https://www.codefactor.io/repository/github/kenexar/kenexar-core"><img src="https://www.codefactor.io/repository/github/kenexar/kenexar-core/badge" alt="CodeFactor" /></a>
    <a align="center" href="https://www.python.org/"><img src="https://img.shields.io/badge/Made%20with-Python-1f425f.svg" alt="Python"/></a>
    <a href="https://github.com/Kenexar/kenexar-core/blob/main/LICENSE"><img alt="GitHub license" src="https://img.shields.io/github/license/Kenexar/kenexar-core"></a>
</div>


## Installation
Here I give you the Installation instruction:

#### On Windows:
- `pip install kenexar-core`

#### On Linux:
- `python3 -m pip install kenexar-core`


And then you can start.

## Contributing
Feel free to open Issues or PR's

### Create your Enviroment

  - 1: clone the current project via: https -> `git clone https://github.com/kenexar/kenexar-core` <br>
  - 2: When you are on Linux/OSX or have an WSL on Win, you can run the setup.sh with `./setup.sh`
    ##### When the setup.sh is not working, follow these steps.
    - 2.1: Create a virtual enviroment with `python3 -m venv venv/` and activate it `venv/scripts/activate`.<br>
    - 2.2: Install the requirements with `pip install -r req.txt`. <br>
  - 3: Have fun Developing! :D




Project by [exersalza "Julian J."](https://github.com/exersalza)

==> kenexar-core-2.2.0.tar.gz: kenexar-core-2.2.0/README.md <==
<br />
<div align="center">
  <a href="https://github.com/Kenexar/kenexar-core">
    <img src="https://cloud.kenexar.eu/s/bQBApT3Sa56KBij/preview" alt="Logo" width="80" height="80">
  </a>

  <h3 align="center">Kenexar-Core</h3>

  <p align="center">
    This is the base Package for the most python projects from the KenexarEU Team.<br> Also is this project a collection of the most used code snippets.
    <br />
    <a href="https://kenexar.github.io/kenexar-core/"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://github.com/Kenexar/kenexar-core/issues">Report Bug</a>
    ·
    <a href="https://github.com/Kenexar/kenexar-core/issues">Request Feature</a>
  </p>
  <a align="center" href="https://www.codefactor.io/repository/github/kenexar/kenexar-core"><img src="https://www.codefactor.io/repository/github/kenexar/kenexar-core/badge" alt="CodeFactor" /></a>
    <a align="center" href="https://www.python.org/"><img src="https://img.shields.io/badge/Made%20with-Python-1f425f.svg" alt="Python"/></a>
    <a href="https://github.com/Kenexar/kenexar-core/blob/main/LICENSE"><img alt="GitHub license" src="https://img.shields.io/github/license/Kenexar/kenexar-core"></a>
    <img alt="lines of code" src="https://img.shields.io/tokei/lines/github/Kenexar/kenexar-core?&style=plastic&label=Lines%20of%20Code">
</div>


## Installation
Here I give you the Installation instruction:

#### On Windows:
- `pip install kenexar-core`

#### On Linux:
- `python3 -m pip install kenexar-core`


And then you can start.

## Contributing
Feel free to open Issues or PR's

### Create your Enviroment

  - 1: clone the current project via: https -> `git clone https://github.com/kenexar/kenexar-core` <br>
  - 2: When you are on Linux/OSX or have a WSL on Win, you can run the setup.sh with `./setup.sh`
    ##### When the setup.sh is not working, follow these steps.
    - 2.1: Create a virtual enviroment with `python3 -m venv venv/` and activate it `venv/Scripts/activate`.<br>
    - 2.2: Install the requirements with `pip install -r req`. <br>
  - 3: Have fun Developing! :D




Project by [exersalza "Julian J."](https://github.com/exersalza)
